cmd

package
v0.0.0-...-878bea8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 5, 2026 License: MIT Imports: 21 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var AssetsFS embed.FS

AssetsFS is set from main to provide embedded assets.

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately.

Types

type BatchJob

type BatchJob struct {
	InputFile  string
	OutputFile string
	Content    string
}

type CachedFile

type CachedFile struct {
	Content string
	ModTime time.Time
}

CachedFile stores the rendered HTML and modification time for a single file.

type PreviewData

type PreviewData = views.ServeData

Jump to